==> easy_onvif-2.1.0-dev.2.tar.gz: lib/device_management.dart <==
library device_management;

export 'src/model/device_management/analytics_capabilities.dart';
export 'src/model/device_management/capabilities.dart';
export 'src/model/device_management/date_time.dart';
export 'src/model/device_management/date.dart';
export 'src/model/device_management/device_capabilities.dart';
export 'src/model/device_management/device_service_capabilities.dart';
export 'src/model/device_management/dns_information.dart';
export 'src/model/device_management/dns_entry.dart';
export 'src/model/device_management/event_capabilities.dart';
export 'src/model/device_management/get_capabilities_response.dart';
export 'src/model/device_management/get_services_response.dart';
export 'src/model/device_management/get_device_information_response.dart';
export 'src/model/device_management/get_discovery_mode_response.dart';
export 'src/model/device_management/get_dns_response.dart';
export 'src/model/device_management/get_hostname_response.dart';
export 'src/model/device_management/get_network_protocols_response.dart';
export 'src/model/device_management/get_ntp_response.dart';
export 'src/model/device_management/get_service_capabilities_response.dart';
export 'src/model/device_management/get_system_date_and_time_response.dart';
export 'src/model/device_management/get_system_uris_response.dart';
export 'src/model/device_management/get_users_response.dart';
export 'src/model/device_management/hostname_information.dart';
export 'src/model/device_management/io_capabilities.dart';
export 'src/model/device_management/media_capabilities.dart';
export 'src/model/device_management/network_capabilities.dart';
export 'src/model/device_management/network_protocol.dart';
export 'src/model/device_management/ntp_information.dart';
export 'src/model/device_management/ntp.dart';
export 'src/model/device_management/ptz_capabilities.dart';
export 'src/model/device_management/real_time_streaming_capabilities.dart';
export 'src/model/device_management/security_capabilities.dart';
export 'src/model/device_management/service.dart';
export 'src/model/device_management/system.dart';
export 'src/model/device_management/system_capabilities.dart';
export 'src/model/device_management/system_date_and_time.dart';
export 'src/model/device_management/system_log_uris.dart';
export 'src/model/device_management/system_log.dart';
export 'src/model/device_management/time_zone.dart';
export 'src/model/device_management/time.dart';
export 'src/model/device_management/user.dart';
export 'src/model/device_management/version.dart';

==> easy_onvif-2.1.2.tar.gz: lib/device_management.dart <==
/// device management classes
library device_management;

export 'src/model/device_management/analytics_capabilities.dart';
export 'src/model/device_management/capabilities.dart';
export 'src/model/device_management/date_time.dart';
export 'src/model/device_management/date.dart';
export 'src/model/device_management/device_capabilities.dart';
export 'src/model/device_management/device_service_capabilities.dart';
export 'src/model/device_management/dns_information.dart';
export 'src/model/device_management/dns_entry.dart';
export 'src/model/device_management/event_capabilities.dart';
export 'src/model/device_management/get_capabilities_response.dart';
export 'src/model/device_management/get_services_response.dart';
export 'src/model/device_management/get_device_information_response.dart';
export 'src/model/device_management/get_discovery_mode_response.dart';
export 'src/model/device_management/get_dns_response.dart';
export 'src/model/device_management/get_hostname_response.dart';
export 'src/model/device_management/get_network_protocols_response.dart';
export 'src/model/device_management/get_ntp_response.dart';
export 'src/model/device_management/get_service_capabilities_response.dart';
export 'src/model/device_management/get_storage_configuration_response.dart';
export 'src/model/device_management/get_storage_configurations_response.dart';
export 'src/model/device_management/get_system_support_information_response.dart';
export 'src/model/device_management/get_system_date_and_time_response.dart';
export 'src/model/device_management/get_system_log_response.dart';
export 'src/model/device_management/get_system_uris_response.dart';
export 'src/model/device_management/get_users_response.dart';
export 'src/model/device_management/hostname_information.dart';
export 'src/model/device_management/io_capabilities.dart';
export 'src/model/device_management/media_capabilities.dart';
export 'src/model/device_management/network_capabilities.dart';
export 'src/model/device_management/network_protocol.dart';
export 'src/model/device_management/ntp_information.dart';
export 'src/model/device_management/ntp.dart';
export 'src/model/device_management/ptz_capabilities.dart';
export 'src/model/device_management/real_time_streaming_capabilities.dart';
export 'src/model/device_management/security_capabilities.dart';
export 'src/model/device_management/service.dart';
export 'src/model/device_management/system.dart';
export 'src/model/device_management/system_capabilities.dart';
export 'src/model/device_management/storage_configuration_data.dart';
export 'src/model/device_management/storage_configuration.dart';
export 'src/model/device_management/system_date_and_time.dart';
export 'src/model/device_management/system_information.dart';
export 'src/model/device_management/system_log_uri_list.dart';
export 'src/model/device_management/system_log_uri.dart';
export 'src/model/device_management/system_reboot_response.dart';
export 'src/model/device_management/time_zone.dart';
export 'src/model/device_management/time.dart';
export 'src/model/device_management/user.dart';
export 'src/model/device_management/version.dart';
